Int (imandrax-ocaml.Imandrax_ocaml_prelude.Prelude_extracted.Int)

`type t = int`
`val (+) : int -> int -> int`
`val (-) : int -> int -> int`
`val (~-) : int -> int`
`val (*) : int -> int -> int`
`val (/) : int -> int -> int`
`val (mod) : int -> int -> int`
`val (<) : int -> int -> bool`
`val (<=) : int -> int -> bool`
`val (>) : int -> int -> bool`
`val (>=) : int -> int -> bool`
`val min : int -> int -> int`
`val max : int -> int -> int`
`val abs : int -> int`
`val to_string : t -> string`

Conversion to a string. Only works for nonnegative numbers

`val compare : t -> t -> Imandrax_util.Z.t`
`val equal : 'a -> 'a -> bool`
`val pp : Stdlib.Format.formatter -> Imandrax_util.Z.t -> unit`
`val of_caml_int : int -> Imandrax_util.Z.t`
`val for_ : int -> int -> (int -> unit) -> unit`
`val pow_ : int -> Imandrax_util.Z.t -> int`
`val pow : t -> t -> t`
`val for_down_to : int -> int -> (int -> unit) -> unit`
`val mod_zero_prod : int -> int -> int -> bool`
`val mod_sub_id : int -> int -> bool`